==> apigateway-0.33.0-sources.jar: software/amazon/awscdk/services/apigateway/UsagePlan.java <==
package software.amazon.awscdk.services.apigateway;

@javax.annotation.Generated(value = "jsii-pacmak/0.11.0 (build 3d6415e)", date = "2019-05-30T15:06:14.465Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.UsagePlan")
public class UsagePlan extends software.amazon.awscdk.Resource {
    protected UsagePlan(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public UsagePlan(final software.amazon.awscdk.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.UsagePlanProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }
    public UsagePlan(final software.amazon.awscdk.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Adds an ApiKey.
     */
    public void addApiKey(final software.amazon.awscdk.services.apigateway.IApiKey apiKey) {
        this.jsiiCall("addApiKey", Void.class, new Object[] { java.util.Objects.requireNonNull(apiKey, "apiKey is required") });
    }

    /**
     * Adds an apiStage.
     */
    public void addApiStage(final software.amazon.awscdk.services.apigateway.UsagePlanPerApiStage apiStage) {
        this.jsiiCall("addApiStage", Void.class, new Object[] { java.util.Objects.requireNonNull(apiStage, "apiStage is required") });
    }

    /**
     */
    public java.lang.String getUsagePlanId() {
        return this.jsiiGet("usagePlanId", java.lang.String.class);
    }
}

==> apigateway-0.34.0-sources.jar: software/amazon/awscdk/services/apigateway/UsagePlan.java <==
package software.amazon.awscdk.services.apigateway;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:12:46.540Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.apigateway.$Module.class, fqn = "@aws-cdk/aws-apigateway.UsagePlan")
public class UsagePlan extends software.amazon.awscdk.Resource {
    protected UsagePlan(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public UsagePlan(final software.amazon.awscdk.Construct scope, final java.lang.String id, @javax.annotation.Nullable final software.amazon.awscdk.services.apigateway.UsagePlanProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public UsagePlan(final software.amazon.awscdk.Construct scope, final java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * Adds an ApiKey.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addApiKey(final software.amazon.awscdk.services.apigateway.IApiKey apiKey) {
        this.jsiiCall("addApiKey", Void.class, new Object[] { java.util.Objects.requireNonNull(apiKey, "apiKey is required") });
    }

    /**
     * Adds an apiStage.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addApiStage(final software.amazon.awscdk.services.apigateway.UsagePlanPerApiStage apiStage) {
        this.jsiiCall("addApiStage", Void.class, new Object[] { java.util.Objects.requireNonNull(apiStage, "apiStage is required") });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getUsagePlanId() {
        return this.jsiiGet("usagePlanId", java.lang.String.class);
    }
}
